@@ -3,15 +3,16 @@
 set -x
 glib-gettextize --copy --force
 
-#libtoolize --automake --copy --force
+libtoolize --automake --copy --force
 intltoolize --automake --copy --force
 
 # Scan configure.ac and copy the necessary macros into aclocal.m4.
-aclocal-1.7
+aclocal
 
 autoconf --force
 #autoheader --force
-automake-1.7 --add-missing --copy --force-missing --foreign
+automake --add-missing --copy --force-missing --foreign
 
 # Create needed information files (if it was not done earlier)
 touch NEWS README AUTHORS ChangeLog
+
