@@ -1,4 +1,5 @@
 #include <windows/wsettings.h>
+#include <windows/callbacks.h>
 
 void init_wsettings(GtkWidget* w, AppData* data)
 {
@@ -46,7 +47,9 @@ void settings_module(GtkWidget* button, AppData* data)
 {
     GPtrArray* options;
     GPtrArray* modules;
+    GPtrArray* config_modules;
     Module* module;
+    ConfigModule* config_module;
     gchar* button_name;
     int i;
     
@@ -59,12 +62,27 @@ void settings_module(GtkWidget* button, AppData* data)
             break;
         }
     }
-
+    
+    //g_debug("%d %d", i, modules->len);
+    if(i == modules->len - 1) {
+        show_banner("This module don't have the settings", NULL);	
+	return;    
+    }
+    
+    config_modules = kimi_conf_get_config_modules(data->kimi);
+    
+    for(i = 0; i < config_modules->len; i++){
+        config_module = g_ptr_array_index(config_modules, i);
+	if(strcmp(module->service_name, config_module->id) == 0) {
+	    break;
+	}
+    }
+        
     /* get all settings for module */
-    // options = ...
+    options = kimi_conf_get_options(config_module);
 
     /* show settings for this module */
-    //show_options(NULL, module->service_name, NULL, options);
+    show_options(NULL, module->service_name, NULL, options);
 }
 
 static void save_option(Option* opt, GtkWidget* widget)
@@ -103,7 +121,7 @@ static void save_option(Option* opt, GtkWidget* widget)
 static void on_dialog_response (GtkDialog *dialog, gint response_id, GPtrArray* view_settings)
 {
     int i;
-	GtkWidget* widget;
+    GtkWidget* widget;
     Option* opt;
     GPtrArray* options;
     
