@@ -1,6 +1,10 @@
 #!/bin/sh
 
-for tag in "0.1.0" "0.1.1" "0.1.2" "0.1.3" "tip"; do
+# Before use this script:
+# 1) Copy this script to another location
+# 2) Commit all changes
+
+for tag in $(hg tags | sort -n -k2 | awk '{print $1}'); do
 	hg update $tag 2>&1 > /dev/null
 	echo $tag:
 	for dir in $(find src/ -maxdepth 1 -type d); do
